# import numpy as np


# print(np.corrcoef(np.mat(np.array([float(i)
#       for i in input().split()]).reshape(-1, 31))))


def println():
    print('''
    np.corrcoef(np.mat(np.array([float(i)
                 for i in input().split()]).reshape(-1, 31)))
    ''')
